@@ -56,6 +56,11 @@ QString ContextPrivate::s_applicationId;
 
 #ifndef K_DOXYGEN
 
+namespace
+{
+constexpr auto EVENT_ROLE = "sink-input-by-media-role:event";
+} // namespace
+
 static bool isGoodState(int eol)
 {
     if (eol < 0) {
@@ -91,7 +96,7 @@ static void sink_input_callback(pa_context *context, const pa_sink_input_info *i
         return;
     }
     if (const char *id = pa_proplist_gets(info->proplist, "module-stream-restore.id")) {
-        if (qstrcmp(id, "sink-input-by-media-role:event") == 0) {
+        if (qstrcmp(id, EVENT_ROLE) == 0) {
             qCDebug(PULSEAUDIOQT) << "Ignoring event role sink input.";
             return;
         }
@@ -335,7 +340,6 @@ ContextPrivate::ContextPrivate(Context *q)
 
 Context::~Context()
 {
-    delete d;
 }
 
 ContextPrivate::~ContextPrivate()
@@ -350,6 +354,7 @@ ContextPrivate::~ContextPrivate()
         m_mainloop = nullptr;
     }
 
+    disconnectSignals();
     reset();
 }
 
@@ -538,10 +543,15 @@ void ContextPrivate::contextStateCallback(pa_context *c)
             return;
         }
 
+        // Always synthesize an event stream. Neither PA nor PW have one until the first event sound is played.
+        // This stream will eventually get updated by either the read_cb or the subscription.
+        // https://gitlab.freedesktop.org/pipewire/pipewire/-/issues/4186
+        synthesizeEventStream();
         if (PAOperation(pa_ext_stream_restore_read(c, ext_stream_restore_read_cb, this))) {
             pa_ext_stream_restore_set_subscribe_cb(c, ext_stream_restore_subscribe_cb, this);
             PAOperation(pa_ext_stream_restore_subscribe(c, 1, nullptr, this));
         } else {
+            m_streamRestores.reset();
             qCWarning(PULSEAUDIOQT) << "Failed to initialize stream_restore extension";
         }
     } else if (!PA_CONTEXT_IS_GOOD(state)) {
@@ -597,11 +607,11 @@ void ContextPrivate::moduleCallback(const pa_module_info *info)
 
 void ContextPrivate::streamRestoreCallback(const pa_ext_stream_restore_info *info)
 {
-    if (qstrcmp(info->name, "sink-input-by-media-role:event") != 0) {
+    if (qstrcmp(info->name, EVENT_ROLE) != 0) {
         return;
     }
 
-    const int eventRoleIndex = 1;
+    const int eventRoleIndex = 0;
     StreamRestore *obj = qobject_cast<StreamRestore *>(m_streamRestores.data().value(eventRoleIndex));
 
     if (!obj) {
@@ -644,7 +654,7 @@ void Context::setDefaultSink(const QString &name)
 
     // Change device for all entries in stream-restore database
     d->m_newDefaultSink = name;
-    if (!PAOperation(pa_ext_stream_restore_read(d->m_context, ext_stream_restore_change_sink_cb, d))) {
+    if (!PAOperation(pa_ext_stream_restore_read(d->m_context, ext_stream_restore_change_sink_cb, d.get()))) {
         qCWarning(PULSEAUDIOQT) << "pa_ext_stream_restore_read failed";
     }
 }
@@ -661,7 +671,7 @@ void Context::setDefaultSource(const QString &name)
 
     // Change device for all entries in stream-restore database
     d->m_newDefaultSource = name;
-    if (!PAOperation(pa_ext_stream_restore_read(d->m_context, ext_stream_restore_change_source_cb, d))) {
+    if (!PAOperation(pa_ext_stream_restore_read(d->m_context, ext_stream_restore_change_source_cb, d.get()))) {
         qCWarning(PULSEAUDIOQT) << "pa_ext_stream_restore_read failed";
     }
 }
@@ -737,6 +747,23 @@ void ContextPrivate::checkConnectTries()
     }
 }
 
+void ContextPrivate::disconnectSignals()
+{
+    m_sinks.disconnectSignals();
+    m_sinkInputs.disconnectSignals();
+    m_sources.disconnectSignals();
+    m_sourceOutputs.disconnectSignals();
+    m_clients.disconnectSignals();
+    m_cards.disconnectSignals();
+    m_modules.disconnectSignals();
+    m_streamRestores.disconnectSignals();
+
+    m_server->disconnectSignals();
+
+    QObject::disconnect(q, &Context::stateChanged, nullptr, nullptr);
+    QObject::disconnect(q, &Context::autoConnectingChanged, nullptr, nullptr);
+}
+
 void ContextPrivate::reset()
 {
     m_sinks.reset();
@@ -945,4 +972,32 @@ bool ContextPrivate::hasConnectionTriesLeft() const
     return m_connectTries < maxTries;
 }
 
+void ContextPrivate::synthesizeEventStream()
+{
+    const pa_ext_stream_restore_info info{
+        .name = EVENT_ROLE, //
+        .channel_map = {.channels = 1, .map = {PA_CHANNEL_POSITION_MONO}}, //
+        .volume = {.channels = 1, .values = {PA_VOLUME_NORM}}, //
+        .device = nullptr,
+        .mute = false,
+    };
+    streamRestoreCallback(&info);
+}
+
+void Context::loadModule(const QString &name, const QString &argument)
+{
+    // We could provide callback forwarding here, unfortunately that is a bit complicated because we don't do this elsewhere, so we'd have to invent
+    // new machinery. Additionally complicated by the fact that the caller may wish to supply a capturing lambda which doesn't decay to a pointer callable.
+    // Let's not do this until someone presents a good use case. Worst case, a caller can just use the context directly and side step this function.
+    if (!PAOperation(pa_context_load_module(d->m_context, qUtf8Printable(name), qUtf8Printable(argument), /*callback*/ nullptr, /*userdata*/ nullptr))) {
+        qCWarning(PULSEAUDIOQT) << "pa_context_load_module() failed" << name << argument;
+    }
+}
+
+void Context::unloadModule(PulseAudioQt::Module *module)
+{
+    if (!PAOperation(pa_context_unload_module(d->m_context, module->index(), /*callback*/ nullptr, /*userdata*/ nullptr))) {
+        qCWarning(PULSEAUDIOQT) << "pa_context_load_module() failed" << module->index() << module->name() << module->argument();
+    }
+}
 } // PulseAudioQt
