@@ -27,10 +27,14 @@ class PULSEAUDIOQT_EXPORT Profile : public PulseObject
     Q_PROPERTY(quint32 sourceCount READ sourceCount NOTIFY sourceCountChanged)
 
 public:
-    enum Availability { Unknown, Available, Unavailable };
+    enum Availability {
+        Unknown,
+        Available,
+        Unavailable
+    };
     Q_ENUM(Availability)
 
-    ~Profile();
+    ~Profile() override;
 
     /**
      * A human readable description.
@@ -87,7 +91,7 @@ protected:
     /** @private */
     explicit Profile(QObject *parent);
     /** @private */
-    class ProfilePrivate *const d;
+    std::unique_ptr<class ProfilePrivate> d;
 
     friend class Device;
     friend class CardPrivate;
