@@ -7,6 +7,8 @@
 #include "server.h"
 #include <pulse/introspect.h>
 
+#include <QTimer>
+
 namespace PulseAudioQt
 {
 class ServerPrivate
@@ -21,8 +23,11 @@ public:
     QString m_defaultSourceName;
     Sink *m_defaultSink;
     Source *m_defaultSource;
-    bool m_isPipeWire = false;
+    bool m_isPipeWire = true;
+    bool m_hasWirePlumber = true;
+    QTimer m_wirePlumberFindTimer;
 
     void update(const pa_server_info *info);
+    void findWirePlumber();
 };
 }
